pub struct DockerFileConfig {
pub build_task: Option<Id>,
pub image: Option<String>,
pub run_prune: Option<bool>,
pub run_setup: Option<bool>,
pub start_task: Option<Id>,
pub template: Option<FilePath>,
}Expand description
Configures Dockerfile generation. When configured at the workspace-level,
applies to all projects, but can be overridden at the project-level.
Fields
build_task: Option<Id>A task identifier within the current project for building the project. If not defined, will skip the build step.
image: Option<String>The base Docker image to use. If not defined, will use the provided image from the first matching toolchain, otherwise defaults to “scratch”.
run_prune: Option<bool>Run the moon docker prune command after building the
project, but before starting it.
@since 2.0.0
run_setup: Option<bool>Run the moon docker setup command after scaffolding,
but before building the project.
@since 2.0.0
start_task: Option<Id>A task identifier within the current project for starting the project
within the CMD instruction. If not defined, will skip the start step
and not include the CMD instruction.
template: Option<FilePath>A custom template file, relative from the workspace root, to use when
rendering the Dockerfile. Powered by Tera.
@since 2.0.0