pub struct HasherConfig {
pub ignore_patterns: Vec<GlobPath>,
pub ignore_missing_patterns: Vec<GlobPath>,
pub optimization: HasherOptimization,
pub walk_strategy: HasherWalkStrategy,
pub warn_on_missing_inputs: bool,
}Expand description
Configures aspects of the content hashing engine.
Fields
ignore_patterns: Vec<GlobPath>Filters file paths that match a configured glob pattern
when a hash is being generated. Patterns are workspace relative,
so prefixing with ** is recommended.
@since 1.10.0
ignore_missing_patterns: Vec<GlobPath>When warnOnMissingInputs is enabled, filters missing file
paths from logging a warning.
@since 1.10.0
optimization: HasherOptimizationThe optimization to use when hashing.
walk_strategy: HasherWalkStrategyThe strategy to use when walking the file system.
warn_on_missing_inputs: boolLogs a warning when a task has configured an explicit file path input, and that file does not exist when hashing.