pub struct InheritedTasksConfig {
pub schema: String,
pub extends: Option<ExtendsFrom>,
pub file_groups: FxHashMap<Id, Vec<Input>>,
pub implicit_deps: Vec<TaskDependency>,
pub implicit_inputs: Vec<Input>,
pub inherited_by: Option<InheritedByConfig>,
pub tasks: BTreeMap<Id, TaskConfig>,
pub task_options: Option<TaskOptionsConfig>,
}Expand description
Configures tasks and task related settings that’ll be inherited by all matching projects. Docs: https://moonrepo.dev/docs/config/tasks
Fields
schema: Stringextends: Option<ExtendsFrom>Extends one or many tasks configuration files. Supports a relative file path or a secure URL. @since 1.12.0
file_groups: FxHashMap<Id, Vec<Input>>A map of group identifiers to a list of file paths, globs, and environment variables, that can be referenced from tasks.
implicit_deps: Vec<TaskDependency>Task dependencies (deps) that will be automatically injected into every
task that inherits this configuration.
implicit_inputs: Vec<Input>Task inputs (inputs) that will be automatically injected into every
task that inherits this configuration.
inherited_by: Option<InheritedByConfig>A map of conditions that define which projects will inherit these tasks and configuration. If not defined, will be inherited by all projects. @since 2.0.0
tasks: BTreeMap<Id, TaskConfig>A map of identifiers to task objects. Tasks represent the work-unit of a project, and can be ran in the action pipeline.
task_options: Option<TaskOptionsConfig>Default task options for all inherited tasks. @since 1.20.0