pub struct PartialRemoteConfig {
pub api: Option<RemoteApi>,
pub auth: Option<<RemoteAuthConfig as Config>::Partial>,
pub cache: Option<<RemoteCacheConfig as Config>::Partial>,
pub host: Option<String>,
pub mtls: Option<<RemoteMtlsConfig as Config>::Partial>,
pub tls: Option<<RemoteTlsConfig as Config>::Partial>,
}Expand description
Configures the remote service, powered by the Bazel Remote Execution API. @since 1.30.0
Fields
api: Option<RemoteApi>The API format of the remote service. @since 1.32.0
auth: Option<<RemoteAuthConfig as Config>::Partial>Connect to the host using basic HTTP authentication. @since 1.32.0
cache: Option<<RemoteCacheConfig as Config>::Partial>Configures the action cache (AC) and content addressable cache (CAS).
host: Option<String>The remote host to connect and send requests to. Supports gRPC protocols.
mtls: Option<<RemoteMtlsConfig as Config>::Partial>Connect to the host using server and client authentication with mTLS. This takes precedence over normal TLS.
tls: Option<<RemoteTlsConfig as Config>::Partial>Connect to the host using server-only authentication with TLS.