pub struct PartialTemplateConfig {
pub schema: Option<String>,
pub description: Option<String>,
pub destination: Option<String>,
pub extends: Option<OneOrMany<Id>>,
pub id: Option<Id>,
pub title: Option<String>,
pub variables: Option<FxHashMap<String, <TemplateVariable as Config>::Partial>>,
}Expand description
Configures a template and its files to be scaffolded. Docs: https://moonrepo.dev/docs/config/template
Fields
schema: Option<String>description: Option<String>A description on what the template scaffolds.
destination: Option<String>A pre-populated destination to scaffold to, relative from the
workspace root when leading with /, otherwise the working directory.
extends: Option<OneOrMany<Id>>Extends one or many other templates.
id: Option<Id>Overrides the identifier of the template, instead of using the folder name.
title: Option<String>A human-readable title for the template.
variables: Option<FxHashMap<String, <TemplateVariable as Config>::Partial>>A map of variables that’ll be interpolated within each template file. Variables can also be populated by passing command line arguments.