pub struct PartialWorkspaceConfig {Show 16 fields
pub schema: Option<String>,
pub codeowners: Option<<CodeownersConfig as Config>::Partial>,
pub constraints: Option<<ConstraintsConfig as Config>::Partial>,
pub default_project: Option<Id>,
pub docker: Option<<DockerConfig as Config>::Partial>,
pub experiments: Option<<ExperimentsConfig as Config>::Partial>,
pub extends: Option<ExtendsFrom>,
pub generator: Option<<GeneratorConfig as Config>::Partial>,
pub hasher: Option<<HasherConfig as Config>::Partial>,
pub notifier: Option<<NotifierConfig as Config>::Partial>,
pub pipeline: Option<<PipelineConfig as Config>::Partial>,
pub projects: Option<<WorkspaceProjects as Config>::Partial>,
pub remote: Option<<RemoteConfig as Config>::Partial>,
pub telemetry: Option<bool>,
pub vcs: Option<<VcsConfig as Config>::Partial>,
pub version_constraint: Option<VersionReq>,
}Expand description
Configures all aspects of the moon workspace. Docs: https://moonrepo.dev/docs/config/workspace
Fields
schema: Option<String>codeowners: Option<<CodeownersConfig as Config>::Partial>Configures code ownership rules for generating a CODEOWNERS file.
@since 1.8.0
constraints: Option<<ConstraintsConfig as Config>::Partial>Configures boundaries and constraints between projects.
default_project: Option<Id>The default/main project within the workspace. When a task is ran without a project, the default will be used. @since 2.0.0
docker: Option<<DockerConfig as Config>::Partial>Configures Docker integration for the workspace. @since 1.27.0
experiments: Option<<ExperimentsConfig as Config>::Partial>Configures experiments across the entire moon workspace. @since 1.11.0
extends: Option<ExtendsFrom>Extends one or many workspace configuration file. Supports a relative file path or a secure URL. @since 1.12.0
generator: Option<<GeneratorConfig as Config>::Partial>Configures the generator for scaffolding from templates.
hasher: Option<<HasherConfig as Config>::Partial>Configures aspects of the content hashing engine.
notifier: Option<<NotifierConfig as Config>::Partial>Configures how and where notifications are sent.
pipeline: Option<<PipelineConfig as Config>::Partial>Configures aspects of the action pipeline.
projects: Option<<WorkspaceProjects as Config>::Partial>Configures all projects within the workspace to create a project graph. Accepts a list of globs, a mapping of projects to relative file paths, or both values.
remote: Option<<RemoteConfig as Config>::Partial>Configures aspects of the remote service.
telemetry: Option<bool>Collects anonymous usage information, and checks for new moon versions.
vcs: Option<<VcsConfig as Config>::Partial>Configures the version control system (VCS). Also known as source code management (SCM).
version_constraint: Option<VersionReq>Requires a specific version of the moon binary.