pub struct VcsConfig {
pub client: VcsClient,
pub default_branch: String,
pub hooks: FxHashMap<String, Vec<String>>,
pub hook_format: VcsHookFormat,
pub provider: VcsProvider,
pub remote_candidates: Vec<String>,
pub sync: bool,
}Expand description
Configures the version control system (VCS).
Fields
client: VcsClientThe VCS client being utilized by the repository.
default_branch: StringThe default branch / base.
hooks: FxHashMap<String, Vec<String>>A map of hooks to a list of commands to run when the hook is triggered. @since 1.9.0
hook_format: VcsHookFormatThe format to use for generated VCS hook files. @since 1.29.0
provider: VcsProviderThe upstream version control provider, where the repository source code is stored. @since 1.8.0
remote_candidates: Vec<String>List of remote’s in which to compare branches against.
sync: boolAutomatically generate hooks and scripts during a sync operation,
based on the hooks setting.
@since 1.9.0